import { reactive, defineComponent, ref, computed, onMounted, watchEffect, toRefs, resolveComponent, resolveDirective, openBlock, createElementBlock, normalizeStyle, unref, createVNode, withCtx, withDirectives, createElementVNode, renderSlot, withKeys, Fragment, renderList, createBlock, mergeProps, createCommentVNode, vShow, createTextVNode, toDisplayString, createSlots, resolveDynamicComponent, normalizeProps, guardReactiveProps } from "vue";
import { ElNotification, ElMessage, ElMessageBox } from "element-plus";
import { useRoute } from "vue-router";
const hooksName = {
  beforeSubmitHandler: "beforeSubmitHandler",
  beforedisabledHandler: "beforedisabledHandler",
  afterdisabledHandler: "afterdisabledHandler",
  beforeAddHandler: "beforeAddHandler",
  beforeEditHandler: "beforeEditHandler",
  beforeQueryHandler: "beforeQueryHandler",
  afterQueryHandler: "afterQueryHandler",
  beforeDeteleHandler: "beforeDeteleHandler",
  afterDeteleHandler: "afterDeteleHandler",
  beforeTableLazyHandler: "beforeTableLazyHandler"
};
function useHooks(hooks = { debug: false }) {
  const state = reactive({
    hooks: {}
  });
  Object.keys(hooks).forEach((item) => {
    if (item !== "debug") {
      state.hooks[item] = hooks[item];
    }
  });
  const hookHandler = (hookName, data) => {
    let res = false;
    try {
      if (hooks.debug) {
        console.group("DeBug\uFF1A", hookName);
        console.table(data.Data);
        console.groupEnd();
      }
      res = state.hooks[hookName](data);
    } catch (error) {
      res = true;
    }
    return res;
  };
  return {
    hookHandler
  };
}
const SystemDefaultParameters = {
  searchFormCollapse: true,
  labelWidth: 120,
  menuAlign: "left",
  menuWidth: 310,
  pageSizes: [10, 20, 50, 100],
  apiName: {
    query: "query",
    add: "add",
    edit: "edit",
    delete: "delete",
    deleteFlag: "deleteFlag",
    remove: "remove"
  },
  permission: {
    add: "add",
    edit: "edit",
    delete: "delete",
    deleteFlag: "deleteFlag",
    remove: "remove"
  },
  CrudRequest: () => {
  }
};
let CrudRequest;
let SystemParameters;
const InitSystem = (options) => {
  let opt = {};
  Object.keys(options).forEach((key) => {
    if (key === "CrudRequest") {
      CrudRequest = options.CrudRequest;
      opt["CrudRequest"] = options.CrudRequest;
    } else {
      opt[key] = options[key];
    }
  });
  SystemParameters = DataMerger(SystemDefaultParameters, opt);
};
const CRUD_Notification = (title, type = "success") => {
  ElNotification({
    title,
    type,
    offset: 70,
    duration: 2500
  });
};
function DeepClone(Obj) {
  let newObj;
  try {
    newObj = Array.isArray(Obj) ? [] : {};
    if (Obj === null)
      newObj = null;
  } catch (error) {
    newObj = {};
  }
  for (const attr in Obj) {
    if (typeof Obj[attr] === "object") {
      newObj[attr] = DeepClone(Obj[attr]);
    } else {
      newObj[attr] = Obj[attr];
    }
  }
  return newObj;
}
function DataMerger(Obj1, Obj2) {
  let newObj = DeepClone(Obj1);
  for (var key in Obj2) {
    if (newObj.hasOwnProperty(key)) {
      if (typeof Obj2[key] === "object") {
        newObj[key] = DataMerger(newObj[key], Obj2[key]);
      } else {
        newObj[key] = Obj2[key];
      }
    } else {
      newObj[key] = Obj2[key];
    }
  }
  return newObj;
}
function isObjEqual(obj1, obj2) {
  let res = {};
  let aProps = Object.getOwnPropertyNames(obj1);
  let bProps = Object.getOwnPropertyNames(obj2);
  if (aProps.length === bProps.length) {
    aProps.forEach((e) => {
      if (obj1[e] !== obj2[e])
        res[e] = obj2[e];
    });
  }
  return res;
}
const _hoisted_1 = /* @__PURE__ */ createTextVNode(" \u65B0\u589E ");
const _hoisted_2 = /* @__PURE__ */ createTextVNode(" \u6279\u91CF\u5220\u9664 ");
const _hoisted_3 = { class: "quick-search-area" };
const _hoisted_4 = /* @__PURE__ */ createTextVNode("\u53D6\u6D88");
const _hoisted_5 = /* @__PURE__ */ createTextVNode("\u63D0\u4EA4");
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "index",
  props: {
    url: null,
    source: null,
    rowKey: null,
    rowKeys: null,
    keyName: null,
    queryAfterMount: { type: Boolean, default: false },
    openMultipleSelection: { type: Boolean },
    expand: { type: Boolean, default: true },
    PaginationLayout: { default: "->,total, sizes, prev, pager, next, jumper" },
    fullscreen: { type: Boolean },
    modalWidth: { default: "800px" },
    closeOnPressEscape: { type: Boolean },
    editFooterButton: { type: Boolean, default: true },
    AddInitID: null,
    watchData: null,
    hooks: null,
    wrapperStyle: null,
    permission: { default: () => ["add", "edit", "delete", "deleteFlag", "remove"] }
  },
  emits: ["update:modelValue", "cell-click", "row-contextmenu"],
  setup(__props, { expose, emit }) {
    const props = __props;
    console.log({ props });
    const route = useRoute();
    const searchRef = ref();
    const buttonAreaRef = ref();
    const crudOptions = reactive({
      ...DataMerger(SystemParameters, props.source.options)
    });
    const { hookHandler } = useHooks(props.hooks);
    let CRUDRequest = computed(() => CrudRequest);
    const ElementArrs = ref({ filter: {}, editor: {}, column: {} });
    const tableColumn = ref();
    const tableRef = ref();
    const tableData = ref();
    const originalData = ref();
    const initSearchModel = ref();
    const initEditModel = ref();
    const searchModel = ref({});
    const searchFormValue = ref({});
    const editModel = ref({});
    const editFormValue = ref({});
    const multipleSelection = ref([]);
    const uploadFiles = ref([]);
    const tableLoading = ref(false);
    const FormRef = ref();
    const Mode = ref("add");
    const DialogVisible = ref(false);
    const submitLoading = ref(false);
    const DialogVisibleFooterButton = ref;
    const Pagination = ref({
      current: 1,
      pageSize: 10,
      total: 0
    });
    (() => {
      const { filter, editor, column, columns } = props.source;
      let filterModel = {};
      filter.forEach((item) => {
        if (columns[item].searchDefaultValue !== void 0) {
          filterModel[item] = columns[item].searchDefaultValue;
        } else {
          filterModel[item] = void 0;
        }
        ElementArrs.value.filter[item] = columns[item];
      });
      initSearchModel.value = DeepClone(filterModel);
      searchModel.value = DeepClone(initSearchModel.value);
      let editorModel = {};
      editor.forEach((item) => {
        if (columns[item].addDefaultValue !== void 0) {
          editorModel[item] = columns[item].addDefaultValue;
        } else {
          editorModel[item] = void 0;
        }
        ElementArrs.value.editor[item] = columns[item];
      });
      initEditModel.value = DeepClone(editorModel);
      column.forEach((item) => {
        ElementArrs.value.column[item] = columns[item];
      });
      tableColumn.value = columns;
    })();
    if (route.params.data) {
      console.log("\u8DEF\u7531\u4F20\u53C2\uFF1A", route.params.data);
      let str = route.params.data;
      let obj = JSON.parse(str);
      searchFormValue.value = DataMerger(searchFormValue.value, obj);
    }
    const SearchForm = computed(() => {
      let arr = {};
      const verfily = ["el-input", "el-input-number", "el-select", "el-date-picker"];
      props.source.filter.forEach((key) => {
        if (verfily.includes(ElementArrs.value.filter[key].type)) {
          arr[key] = ElementArrs.value.filter[key];
        }
      });
      return arr;
    });
    const EditorForm = computed(() => {
      let arr = {};
      const verfily = ["el-input", "el-input-number", "el-select", "el-date-picker", "el-cascader", "el-upload"];
      props.source.editor.forEach((key) => {
        if (verfily.includes(ElementArrs.value.editor[key].type)) {
          if (componentState(ElementArrs.value.editor[key], "visible")) {
            arr[key] = ElementArrs.value.editor[key];
          }
        }
      });
      return arr;
    });
    const tableMaxHeight1 = ref(0);
    const tableMaxHeight2 = ref(0);
    onMounted(() => {
      searchRef.value.style.display = "block";
      tableMaxHeight1.value = document.documentElement.clientHeight - 50 - 20 - 40 - 56 - searchRef.value.clientHeight - buttonAreaRef.value.clientHeight;
      searchRef.value.style.display = "none";
      tableMaxHeight2.value = document.documentElement.clientHeight - 50 - 20 - 40 - 56 - buttonAreaRef.value.clientHeight;
      if (props.queryAfterMount)
        queryRecord();
      if (props.watchData) {
        props.watchData.forEach((item) => {
          watchEffect(() => {
            if (editModel.value[item.id]) {
              console.log(editModel.value[item.id]);
              item.data.forEach((i) => {
                i.data[item.id] = editModel.value[item.id];
                watchGetData(i);
              });
            }
          });
        });
      }
      console.log(tableColumn.value);
    });
    const queryRecord = () => {
      tableLoading.value = true;
      const Data = reactive({
        ...searchModel.value,
        ...searchFormValue.value
      });
      if (!hookHandler(hooksName.beforeQueryHandler, { CrudState, Data })) {
        return;
      }
      for (const key in Data) {
        if (Object.prototype.hasOwnProperty.call(Data, key)) {
          if (typeof Data[key] === "string") {
            console.log(Data, key, Data[key]);
            Data[key] = Data[key].trim();
            if (Data[key] === "") {
              Data[key] = void 0;
            }
          }
          if (typeof Data[key] === "object") {
            console.log("\u53D6\u503C\u4E3AObject\uFF0C\u8FD8\u672A\u505A\u5904\u7406");
          }
          if (typeof Data[key] === "number") {
            console.log("\u53D6\u503C\u4E3Anumber\uFF0C\u8FD8\u672A\u505A\u5904\u7406");
          }
        }
      }
      CRUDRequest.value({
        url: props.url,
        name: crudOptions.apiName.query,
        data: {
          pagenum: Pagination.value.current,
          pagesize: Pagination.value.pageSize,
          ...Data
        }
      }).then((response) => {
        const { data, page } = response;
        responseData(data, Data);
        Pagination.value.total = page.total;
        tableLoading.value = false;
      }).catch(() => {
        tableLoading.value = false;
      });
    };
    const responseData = (Data, reqDataSource) => {
      let originalArray = Object.keys(reqDataSource).filter((r) => reqDataSource[r] != void 0);
      if (originalArray.length == 0) {
        originalData.value = Data;
      }
      originalData.value = DeepClone(Data);
      if (!hookHandler(hooksName.afterQueryHandler, { CrudState, Data })) {
        return;
      }
      tableData.value = DeepClone(Data);
    };
    const refresh = () => {
      searchModel.value = DeepClone(initSearchModel.value);
      queryRecord();
    };
    const addRecord = () => {
      editModel.value = DeepClone(initEditModel.value);
      const Data = reactive({ ...editModel.value });
      if (!hookHandler(hooksName.beforeAddHandler, { CrudState, Data })) {
        return;
      }
      Mode.value = "add";
      DialogVisible.value = true;
    };
    const editRecord = (row) => {
      const Data = reactive({
        ...row
      });
      if (!hookHandler(hooksName.beforeEditHandler, { CrudState, Data })) {
        return;
      }
      Object.keys(Data).forEach((key) => {
        editModel.value[key] = Data[key];
        editFormValue.value[key] = Data[key];
      });
      Mode.value = "edit";
      DialogVisible.value = true;
    };
    const handleSubmit = async (formEl) => {
      if (!formEl)
        return;
      await formEl.validate((valid) => {
        if (valid) {
          const Data = reactive({
            ...editModel.value
          });
          if (!hookHandler(hooksName.beforeSubmitHandler, { CrudState, Data })) {
            return;
          }
          if (CrudState.Mode === "add") {
            handleAdd(Data);
          } else {
            handleEdit(Data);
          }
        }
      });
    };
    const handleAdd = (value) => {
      submitLoading.value = true;
      let data = value;
      if (value.FormData instanceof FormData) {
        data = value.FormData;
      }
      CRUDRequest.value({ url: props.url, name: crudOptions.apiName.add, data }).then(() => {
        DialogVisible.value = false;
        CRUD_Notification("\u65B0\u589E\u6210\u529F");
        queryRecord();
        submitLoading.value = false;
      }).catch(() => {
        submitLoading.value = false;
      });
    };
    const handleEdit = (value) => {
      submitLoading.value = true;
      let data = value;
      if (value.FormData instanceof FormData) {
        data = value.FormData;
      } else {
        const key = props.rowKey;
        const keys = reactive({});
        if (props.rowKeys) {
          props.rowKeys.forEach((key2) => {
            keys[key2] = value[key2];
          });
        }
        const Equal = isObjEqual(editFormValue.value, data);
        if (JSON.stringify(Equal) === "{}") {
          submitLoading.value = false;
          return ElMessage({ message: "\u6CA1\u6709\u63D0\u4EA4\u9879\uFF01", grouping: true });
        }
        data = {
          [key]: value[key],
          ...keys,
          ...isObjEqual(editFormValue.value, data)
        };
      }
      CRUDRequest.value({ url: props.url, name: crudOptions.apiName.edit, data }).then(() => {
        DialogVisible.value = false;
        CRUD_Notification("\u4FEE\u6539\u6210\u529F");
        queryRecord();
        submitLoading.value = false;
      }).catch(() => {
        submitLoading.value = false;
      });
    };
    const delFlag = (row) => {
      ElMessageBox.confirm(`\u786E\u5B9A\u8981 \u201C${row.deleteFlag ? "\u542F\u7528" : "\u7981\u7528"}\u201D \u8BE5\u6761\u6570\u636E\u5417\uFF1F`, "\u63D0\u793A", {
        confirmButtonText: "\u786E\u5B9A",
        cancelButtonText: "\u53D6\u6D88",
        type: "warning"
      }).then(() => {
        const Data = reactive({
          row: { ...row },
          [props.rowKey]: row[props.rowKey],
          deleteFlag: row.deleteFlag == 0 ? 1 : 0
        });
        if (!hookHandler(hooksName.beforedisabledHandler, { CrudState, Data })) {
          return;
        }
        CRUDRequest.value({
          url: props.url,
          name: crudOptions.apiName.deleteFlag,
          data: Data
        }).then(() => {
          CRUD_Notification("\u64CD\u4F5C\u6210\u529F");
          queryRecord();
        });
      }).catch(() => {
      });
    };
    const deleteRecord = (row) => {
      ElMessageBox.confirm("\u786E\u5B9A\u8981\u5220\u9664\u672C\u6761\u6570\u636E\u5417\uFF1F", "\u63D0\u793A", {
        confirmButtonText: "\u786E\u5B9A",
        cancelButtonText: "\u53D6\u6D88",
        type: "warning"
      }).then(() => {
        const Data = reactive({
          row: { ...row },
          [props.rowKey]: row[props.rowKey],
          deleteFlag: row.deleteFlag == 0 ? 1 : 0
        });
        if (!hookHandler(hooksName.beforeDeteleHandler, { CrudState, Data })) {
          return;
        }
        CRUDRequest.value({
          url: props.url,
          name: crudOptions.apiName.delete,
          data: Data
        }).then(() => {
          CRUD_Notification("\u5220\u9664\u6210\u529F");
          queryRecord();
        });
      }).catch(() => {
      });
    };
    const deleteMulRecord = () => {
      ElMessageBox.confirm(`\u786E\u5B9A\u8981\u5220\u9664\u8FD9\u51E0\u6761\u6570\u636E\u5417\uFF1F`, "\u63D0\u793A", {
        confirmButtonText: "\u786E\u5B9A",
        cancelButtonText: "\u53D6\u6D88",
        type: "warning"
      }).then(() => {
        const ids = multipleSelection.value.map((selection) => {
          return selection[props.rowKey];
        });
        CRUDRequest.value({
          url: props.url,
          name: crudOptions.apiName.remove,
          data: { [props.rowKey]: ids, selection: multipleSelection.value }
        }).then(() => {
          CRUD_Notification("\u6279\u91CF\u5220\u9664\u6210\u529F");
          multipleSelection.value = [];
          tableRef.value.clearSelection();
          queryRecord();
        });
      }).catch(() => {
      });
    };
    const IsRange = (item) => {
      if (item.formProps) {
        if (item.formProps.type) {
          if (item.range) {
            return item.formProps.type + "range";
          }
          return item.formProps.type;
        }
      }
      return "date";
    };
    const componentState = (column, mode) => {
      if (mode === "disabled") {
        if (typeof column.disabled === "function") {
          return column.disabled(CrudState, Mode.value);
        } else
          return false;
      }
      if (mode === "visible") {
        if (typeof column.visible === "function") {
          return column.visible(CrudState, Mode.value);
        } else
          return true;
      }
    };
    const cellClick = (row, column, cell, event) => {
      emit("cell-click", { row, column, cell, event });
    };
    const rowContextmenu = (row, column, event) => {
      emit("row-contextmenu", { row, column, event }, CrudState);
    };
    const handleSelectionChange = (value) => {
      multipleSelection.value = value;
    };
    const formComponentProps = (props2) => {
      let connectedProps = { ...props2 };
      Object.keys(connectedProps).forEach((key) => {
        if (typeof connectedProps[key] === "function") {
          connectedProps[key] = connectedProps[key].bind(this, CrudState);
          if (key == "disabled") {
            console.log(connectedProps[key]);
          }
        }
      });
      return connectedProps;
    };
    const tableComponentProps = (tableColumn2, scope) => {
      let connectedProps = { ...tableColumn2 };
      Object.keys(connectedProps).forEach((key) => {
        if (typeof connectedProps[key] === "function") {
          connectedProps[key] = connectedProps[key].call(this, CrudState, scope);
        }
      });
      return connectedProps;
    };
    const handleSizeChange = (value) => {
      Pagination.value.pageSize = value;
      const current = Math.floor(Pagination.value.total / Pagination.value.pageSize);
      if (current === 0) {
        Pagination.value.current = 1;
      } else {
        Pagination.value.current = current;
      }
      queryRecord();
    };
    const handleCurrentChange = (value) => {
      Pagination.value.current = value;
      if (Pagination.value.current == null)
        return;
      queryRecord();
    };
    const expandComputed = (props2, item, key) => {
      if (item.type === "el-select") {
        const index = item.formProps.options.findIndex((i) => i.value == props2.row[key]);
        if (index === -1) {
          return props2.row[key];
        }
        return item.formProps.options[index].label;
      } else {
        return props2.row[key];
      }
    };
    const WrapperStyle = computed(() => {
      return { ...props.wrapperStyle };
    });
    const watchGetData = (row) => {
      CRUDRequest.value({ url: row.url, name: row.name, data: row.data }).then((watchDataRes) => {
        ElementArrs.value.editor[row.key].formProps["options"] = watchDataRes.data.map((item) => {
          if (typeof row.label === "string") {
            return {
              value: item[row.value],
              label: item[row.label]
            };
          }
          if (typeof row.label === "object") {
            return {
              value: item[row.value],
              label: item[row.label[0]] + "--" + item[row.label[1]]
            };
          }
        });
      });
    };
    const CrudState = reactive({
      ElementArrs,
      searchModel,
      searchFormValue,
      editModel,
      editFormValue,
      uploadFiles,
      tableLoading,
      Pagination,
      Mode,
      queryRecord
    });
    expose({
      ...toRefs(CrudState)
    });
    return (_ctx, _cache) => {
      const _component_el_input = resolveComponent("el-input");
      const _component_el_form_item = resolveComponent("el-form-item");
      const _component_el_col = resolveComponent("el-col");
      const _component_el_input_number = resolveComponent("el-input-number");
      const _component_el_option = resolveComponent("el-option");
      const _component_el_select = resolveComponent("el-select");
      const _component_el_date_picker = resolveComponent("el-date-picker");
      const _component_el_row = resolveComponent("el-row");
      const _component_el_form = resolveComponent("el-form");
      const _component_el_collapse_transition = resolveComponent("el-collapse-transition");
      const _component_el_button = resolveComponent("el-button");
      const _component_el_empty = resolveComponent("el-empty");
      const _component_el_table_column = resolveComponent("el-table-column");
      const _component_el_descriptions_item = resolveComponent("el-descriptions-item");
      const _component_el_descriptions = resolveComponent("el-descriptions");
      const _component_el_button_group = resolveComponent("el-button-group");
      const _component_el_table = resolveComponent("el-table");
      const _component_el_pagination = resolveComponent("el-pagination");
      const _component_el_cascader = resolveComponent("el-cascader");
      const _component_plus = resolveComponent("plus");
      const _component_el_icon = resolveComponent("el-icon");
      const _component_el_upload = resolveComponent("el-upload");
      const _component_el_scrollbar = resolveComponent("el-scrollbar");
      const _component_el_card = resolveComponent("el-card");
      const _component_el_dialog = resolveComponent("el-dialog");
      const _directive_permission = resolveDirective("permission");
      const _directive_loading = resolveDirective("loading");
      return openBlock(), createElementBlock("div", {
        class: "wrapp",
        style: normalizeStyle(unref(WrapperStyle))
      }, [
        createVNode(_component_el_card, { style: { "border": "0" } }, {
          default: withCtx(() => [
            withDirectives(createVNode(_component_el_collapse_transition, null, {
              default: withCtx(() => [
                createElementVNode("div", {
                  id: "plain",
                  ref_key: "searchRef",
                  ref: searchRef
                }, [
                  renderSlot(_ctx.$slots, "search-form", {
                    editModel: searchModel.value,
                    queryRecord,
                    CrudState
                  }, void 0, true),
                  createVNode(_component_el_form, {
                    model: searchModel.value,
                    "label-width": crudOptions.labelWidth,
                    onKeyup: withKeys(queryRecord, ["enter", "native"])
                  }, {
                    default: withCtx(() => [
                      createVNode(_component_el_row, null, {
                        default: withCtx(() => [
                          renderSlot(_ctx.$slots, "search-form-top", { CrudState }, void 0, true),
                          (openBlock(true), createElementBlock(Fragment, null, renderList(unref(SearchForm), (item, key) => {
                            return openBlock(), createElementBlock(Fragment, null, [
                              item.type === "el-input" ? (openBlock(), createBlock(_component_el_col, {
                                key: 0,
                                md: 6,
                                lg: 6
                              }, {
                                default: withCtx(() => [
                                  createVNode(_component_el_form_item, {
                                    label: item.label
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_el_input, mergeProps({
                                        style: { "width": "100%" },
                                        modelValue: searchModel.value[key],
                                        "onUpdate:modelValue": ($event) => searchModel.value[key] = $event,
                                        clearable: "",
                                        placeholder: "\u6A21\u7CCA\u67E5\u627E"
                                      }, item.formProps), null, 16, ["modelValue", "onUpdate:modelValue"])
                                    ]),
                                    _: 2
                                  }, 1032, ["label"])
                                ]),
                                _: 2
                              }, 1024)) : item.type === "el-input-number" ? (openBlock(), createBlock(_component_el_col, {
                                key: 1,
                                md: 6,
                                lg: 6
                              }, {
                                default: withCtx(() => [
                                  createVNode(_component_el_form_item, {
                                    label: item.label
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_el_input_number, mergeProps({
                                        style: { "width": "100%" },
                                        modelValue: searchModel.value[key],
                                        "onUpdate:modelValue": ($event) => searchModel.value[key] = $event,
                                        placeholder: "\u8BF7\u8F93\u5165"
                                      }, item.formProps), null, 16, ["modelValue", "onUpdate:modelValue"])
                                    ]),
                                    _: 2
                                  }, 1032, ["label"])
                                ]),
                                _: 2
                              }, 1024)) : item.type === "el-select" ? (openBlock(), createBlock(_component_el_col, {
                                key: 2,
                                md: 6,
                                lg: 6
                              }, {
                                default: withCtx(() => [
                                  createVNode(_component_el_form_item, {
                                    label: item.label
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_el_select, mergeProps({
                                        style: { "width": "100%" },
                                        modelValue: searchModel.value[key],
                                        "onUpdate:modelValue": ($event) => searchModel.value[key] = $event,
                                        clearable: "",
                                        placeholder: "\u8BF7\u9009\u62E9"
                                      }, item.formProps), {
                                        default: withCtx(() => [
                                          (openBlock(true), createElementBlock(Fragment, null, renderList(item.formProps.options, (opt) => {
                                            return openBlock(), createBlock(_component_el_option, {
                                              key: opt.value,
                                              label: opt.label,
                                              value: opt.value
                                            }, null, 8, ["label", "value"]);
                                          }), 128))
                                        ]),
                                        _: 2
                                      }, 1040, ["modelValue", "onUpdate:modelValue"])
                                    ]),
                                    _: 2
                                  }, 1032, ["label"])
                                ]),
                                _: 2
                              }, 1024)) : item.type === "el-date-picker" && IsRange(item).includes("range") ? (openBlock(), createBlock(_component_el_col, {
                                key: 3,
                                xs: 12,
                                sm: 12,
                                md: 12,
                                lg: 12
                              }, {
                                default: withCtx(() => [
                                  createVNode(_component_el_form_item, {
                                    label: item.label
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_el_date_picker, mergeProps({
                                        style: { "width": "100%" },
                                        modelValue: searchModel.value[key],
                                        "onUpdate:modelValue": ($event) => searchModel.value[key] = $event,
                                        "start-placeholder": "\u8D77\u59CB",
                                        "range-separator": "\u81F3",
                                        "end-placeholder": "\u7ED3\u675F",
                                        placeholder: "\u8BF7\u9009\u62E9",
                                        clearable: ""
                                      }, item.formProps, {
                                        type: IsRange(item)
                                      }), null, 16, ["modelValue", "onUpdate:modelValue", "type"])
                                    ]),
                                    _: 2
                                  }, 1032, ["label"])
                                ]),
                                _: 2
                              }, 1024)) : item.type === "el-date-picker" && IsRange(item) ? (openBlock(), createBlock(_component_el_col, {
                                key: 4,
                                md: 6,
                                lg: 6
                              }, {
                                default: withCtx(() => [
                                  createVNode(_component_el_form_item, {
                                    label: item.label
                                  }, {
                                    default: withCtx(() => [
                                      createVNode(_component_el_date_picker, mergeProps({
                                        style: { "width": "100%" },
                                        modelValue: searchModel.value[key],
                                        "onUpdate:modelValue": ($event) => searchModel.value[key] = $event,
                                        "start-placeholder": "\u8D77\u59CB",
                                        "range-separator": "\u81F3",
                                        "end-placeholder": "\u7ED3\u675F",
                                        placeholder: "\u8BF7\u9009\u62E9",
                                        clearable: ""
                                      }, item.formProps, {
                                        type: IsRange(item)
                                      }), null, 16, ["modelValue", "onUpdate:modelValue", "type"])
                                    ]),
                                    _: 2
                                  }, 1032, ["label"])
                                ]),
                                _: 2
                              }, 1024)) : createCommentVNode("", true)
                            ], 64);
                          }), 256)),
                          renderSlot(_ctx.$slots, "search-form-bottom", { CrudState }, void 0, true)
                        ]),
                        _: 3
                      })
                    ]),
                    _: 3
                  }, 8, ["model", "label-width", "onKeyup"])
                ], 512)
              ]),
              _: 3
            }, 512), [
              [vShow, !crudOptions.searchFormCollapse]
            ]),
            createElementVNode("div", {
              ref_key: "buttonAreaRef",
              ref: buttonAreaRef,
              class: "button_area"
            }, [
              withDirectives((openBlock(), createBlock(_component_el_button, {
                type: "primary",
                icon: "plus",
                onClick: addRecord
              }, {
                default: withCtx(() => [
                  _hoisted_1
                ]),
                _: 1
              })), [
                [_directive_permission, { permission: __props.permission, access: [crudOptions.permission.add] }]
              ]),
              __props.openMultipleSelection ? withDirectives((openBlock(), createBlock(_component_el_button, {
                key: 0,
                disabled: multipleSelection.value.length <= 0,
                type: "danger",
                icon: "delete",
                onClick: deleteMulRecord
              }, {
                default: withCtx(() => [
                  _hoisted_2
                ]),
                _: 1
              }, 8, ["disabled"])), [
                [_directive_permission, { permission: __props.permission, access: [crudOptions.permission.remove] }]
              ]) : createCommentVNode("", true),
              renderSlot(_ctx.$slots, "button-area", { CrudState }, void 0, true)
            ], 512),
            withDirectives((openBlock(), createBlock(_component_el_table, {
              ref_key: "tableRef",
              ref: tableRef,
              data: tableData.value,
              "row-key": __props.rowKey,
              height: crudOptions.searchFormCollapse ? tableMaxHeight2.value : tableMaxHeight1.value,
              onCellClick: cellClick,
              onRowContextmenu: rowContextmenu,
              onSelectionChange: handleSelectionChange
            }, {
              empty: withCtx(() => [
                createVNode(_component_el_empty, {
                  "image-size": 80,
                  description: "\u6682\u65E0\u6570\u636E"
                })
              ]),
              default: withCtx(() => [
                __props.openMultipleSelection ? (openBlock(), createBlock(_component_el_table_column, {
                  key: 0,
                  type: "selection",
                  width: 44
                })) : createCommentVNode("", true),
                __props.expand ? (openBlock(), createBlock(_component_el_table_column, {
                  key: 1,
                  type: "expand",
                  label: "###",
                  width: 55
                }, {
                  default: withCtx((props2) => [
                    createVNode(_component_el_descriptions, {
                      column: 3,
                      border: ""
                    }, {
                      default: withCtx(() => [
                        (openBlock(true), createElementBlock(Fragment, null, renderList(__props.source.columns, (item, key) => {
                          return openBlock(), createElementBlock(Fragment, { key }, [
                            !item.hidden ? (openBlock(), createBlock(_component_el_descriptions_item, {
                              key: 0,
                              label: item.label
                            }, {
                              default: withCtx(() => [
                                createTextVNode(toDisplayString(expandComputed(props2, item, key)), 1)
                              ]),
                              _: 2
                            }, 1032, ["label"])) : createCommentVNode("", true)
                          ], 64);
                        }), 128))
                      ]),
                      _: 2
                    }, 1024)
                  ]),
                  _: 1
                })) : createCommentVNode("", true),
                (openBlock(true), createElementBlock(Fragment, null, renderList(ElementArrs.value.column, (item, key) => {
                  var _a;
                  return openBlock(), createBlock(_component_el_table_column, mergeProps({
                    key,
                    align: item.align || "left"
                  }, item.tableProps, {
                    width: item.tableProps ? (_a = item.tableProps) == null ? void 0 : _a.width : void 0,
                    label: item.label,
                    prop: key
                  }), createSlots({ _: 2 }, [
                    item.columnSlot ? {
                      name: "default",
                      fn: withCtx((scope) => [
                        (openBlock(), createBlock(resolveDynamicComponent(item.columnSlot.is), normalizeProps(guardReactiveProps(tableComponentProps(item.columnSlot, scope))), null, 16))
                      ])
                    } : void 0
                  ]), 1040, ["align", "width", "label", "prop"]);
                }), 128)),
                renderSlot(_ctx.$slots, "default", {}, void 0, true),
                createVNode(_component_el_table_column, {
                  align: crudOptions.menuAlign || "left",
                  width: props.keyName ? crudOptions.menuWidth : crudOptions.menuWidth - 150
                }, {
                  header: withCtx(() => [
                    createElementVNode("div", _hoisted_3, [
                      props.keyName ? (openBlock(), createBlock(_component_el_input, {
                        key: 0,
                        style: { "width": "150px" },
                        modelValue: searchModel.value[props.keyName],
                        "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => searchModel.value[props.keyName] = $event),
                        placeholder: "\u6A21\u7CCA\u67E5\u627E",
                        clearable: "",
                        onKeyup: withKeys(queryRecord, ["enter", "native"])
                      }, null, 8, ["modelValue", "onKeyup"])) : createCommentVNode("", true),
                      createVNode(_component_el_button_group, null, {
                        default: withCtx(() => [
                          createVNode(_component_el_button, {
                            color: "#67c23a",
                            icon: "search",
                            onClick: queryRecord
                          }),
                          createVNode(_component_el_button, {
                            color: "#e6a23c",
                            icon: "refresh",
                            onClick: refresh
                          }),
                          createVNode(_component_el_button, {
                            color: "#409eff",
                            icon: "expand",
                            onClick: _cache[1] || (_cache[1] = ($event) => crudOptions.searchFormCollapse = !crudOptions.searchFormCollapse)
                          })
                        ]),
                        _: 1
                      })
                    ])
                  ]),
                  default: withCtx((scope) => [
                    renderSlot(_ctx.$slots, "menu-head", { scope }, void 0, true),
                    withDirectives((openBlock(), createBlock(_component_el_button, {
                      plain: "",
                      type: scope.row.deleteFlag ? "danger" : "success",
                      onClick: ($event) => delFlag(scope.row)
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString(scope.row.deleteFlag ? "\u7981\u7528" : "\u542F\u7528"), 1)
                      ]),
                      _: 2
                    }, 1032, ["type", "onClick"])), [
                      [_directive_permission, { permission: __props.permission, access: [crudOptions.permission.deleteFlag] }]
                    ]),
                    withDirectives(createVNode(_component_el_button, {
                      plain: "",
                      type: "primary",
                      icon: "edit",
                      onClick: ($event) => editRecord(scope.row)
                    }, null, 8, ["onClick"]), [
                      [_directive_permission, { permission: __props.permission, access: [crudOptions.permission.edit] }]
                    ]),
                    withDirectives(createVNode(_component_el_button, {
                      type: "danger",
                      icon: "delete",
                      onClick: ($event) => deleteRecord(scope.row)
                    }, null, 8, ["onClick"]), [
                      [_directive_permission, { permission: __props.permission, access: [crudOptions.permission.delete] }]
                    ]),
                    renderSlot(_ctx.$slots, "menu-tail", { scope }, void 0, true)
                  ]),
                  _: 3
                }, 8, ["align", "width"])
              ]),
              _: 3
            }, 8, ["data", "row-key", "height"])), [
              [_directive_loading, tableLoading.value]
            ]),
            createVNode(_component_el_pagination, {
              style: { "margin-top": "20px" },
              background: "",
              currentPage: Pagination.value.current,
              "onUpdate:currentPage": _cache[2] || (_cache[2] = ($event) => Pagination.value.current = $event),
              onSizeChange: handleSizeChange,
              onCurrentChange: handleCurrentChange,
              "page-sizes": crudOptions.pageSizes,
              "page-size": Pagination.value.pageSize,
              layout: __props.PaginationLayout,
              total: Pagination.value.total
            }, null, 8, ["currentPage", "page-sizes", "page-size", "layout", "total"]),
            createVNode(_component_el_dialog, {
              "custom-class": "DialogVisible",
              ref: "dialogRef",
              modelValue: DialogVisible.value,
              "onUpdate:modelValue": _cache[5] || (_cache[5] = ($event) => DialogVisible.value = $event),
              title: Mode.value === "add" ? "\u65B0\u589E" : "\u4FEE\u6539",
              width: "50%",
              "destroy-on-close": ""
            }, createSlots({
              default: withCtx(() => [
                createVNode(_component_el_card, {
                  class: "edit-form-card",
                  shadow: "never"
                }, {
                  default: withCtx(() => [
                    createVNode(_component_el_scrollbar, {
                      height: "350px",
                      "max-height": "350px"
                    }, {
                      default: withCtx(() => [
                        renderSlot(_ctx.$slots, "edit-form", {
                          editModel: editModel.value,
                          handleSubmit,
                          CrudState
                        }, void 0, true),
                        createVNode(_component_el_form, {
                          id: "DialogVisible-edit-form",
                          class: "edit-form",
                          ref_key: "FormRef",
                          ref: FormRef,
                          model: editModel.value,
                          "label-width": crudOptions.labelWidth
                        }, {
                          default: withCtx(() => [
                            renderSlot(_ctx.$slots, "edit-form-top-item", {
                              editModel: editModel.value,
                              handleSubmit,
                              CrudState
                            }, void 0, true),
                            (openBlock(true), createElementBlock(Fragment, null, renderList(unref(EditorForm), (item, key) => {
                              return openBlock(), createElementBlock(Fragment, { key }, [
                                item.type === "el-input" ? (openBlock(), createBlock(_component_el_form_item, {
                                  key: 0,
                                  label: item.label,
                                  prop: key,
                                  rules: item.rules
                                }, {
                                  default: withCtx(() => [
                                    createVNode(_component_el_input, mergeProps({
                                      modelValue: editModel.value[key],
                                      "onUpdate:modelValue": ($event) => editModel.value[key] = $event,
                                      clearable: "",
                                      placeholder: "\u8BF7\u8F93\u5165",
                                      disabled: componentState(item, "disabled")
                                    }, item.formProps), null, 16, ["modelValue", "onUpdate:modelValue", "disabled"])
                                  ]),
                                  _: 2
                                }, 1032, ["label", "prop", "rules"])) : item.type === "el-input-number" ? (openBlock(), createBlock(_component_el_form_item, {
                                  key: 1,
                                  label: item.label,
                                  prop: key,
                                  rules: item.rules
                                }, {
                                  default: withCtx(() => [
                                    createVNode(_component_el_input_number, mergeProps({
                                      modelValue: editModel.value[key],
                                      "onUpdate:modelValue": ($event) => editModel.value[key] = $event,
                                      placeholder: "\u8BF7\u8F93\u5165",
                                      disabled: componentState(item, "disabled")
                                    }, item.formProps), null, 16, ["modelValue", "onUpdate:modelValue", "disabled"])
                                  ]),
                                  _: 2
                                }, 1032, ["label", "prop", "rules"])) : item.type === "el-select" ? (openBlock(), createBlock(_component_el_form_item, {
                                  key: 2,
                                  label: item.label,
                                  prop: key,
                                  rules: item.rules
                                }, {
                                  default: withCtx(() => [
                                    createVNode(_component_el_select, mergeProps({
                                      style: { "width": "220px" },
                                      modelValue: editModel.value[key],
                                      "onUpdate:modelValue": ($event) => editModel.value[key] = $event,
                                      clearable: "",
                                      placeholder: "\u8BF7\u9009\u62E9",
                                      disabled: componentState(item, "disabled")
                                    }, item.formProps), {
                                      default: withCtx(() => [
                                        (openBlock(true), createElementBlock(Fragment, null, renderList(item.formProps.options, (opt) => {
                                          return openBlock(), createBlock(_component_el_option, {
                                            key: opt.value,
                                            label: opt.label,
                                            value: opt.value
                                          }, null, 8, ["label", "value"]);
                                        }), 128))
                                      ]),
                                      _: 2
                                    }, 1040, ["modelValue", "onUpdate:modelValue", "disabled"])
                                  ]),
                                  _: 2
                                }, 1032, ["label", "prop", "rules"])) : item.type === "el-date-picker" ? (openBlock(), createBlock(_component_el_form_item, {
                                  key: 3,
                                  label: item.label,
                                  prop: key,
                                  rules: item.rules
                                }, {
                                  default: withCtx(() => [
                                    createVNode(_component_el_date_picker, mergeProps({
                                      modelValue: editModel.value[key],
                                      "onUpdate:modelValue": ($event) => editModel.value[key] = $event,
                                      clearable: "",
                                      placeholder: "\u8BF7\u9009\u62E9",
                                      disabled: componentState(item, "disabled")
                                    }, item.formProps), null, 16, ["modelValue", "onUpdate:modelValue", "disabled"])
                                  ]),
                                  _: 2
                                }, 1032, ["label", "prop", "rules"])) : item.type === "el-cascader" ? (openBlock(), createBlock(_component_el_form_item, {
                                  key: 4,
                                  label: item.label,
                                  prop: key,
                                  rules: item.rules
                                }, {
                                  default: withCtx(() => [
                                    createVNode(_component_el_cascader, mergeProps({
                                      modelValue: editModel.value[key],
                                      "onUpdate:modelValue": ($event) => editModel.value[key] = $event,
                                      props: item.formProps.props,
                                      placeholder: "\u8BF7\u9009\u62E9",
                                      "show-all-levels": false,
                                      disabled: componentState(item, "disabled")
                                    }, item.formProps), null, 16, ["modelValue", "onUpdate:modelValue", "props", "disabled"])
                                  ]),
                                  _: 2
                                }, 1032, ["label", "prop", "rules"])) : item.type === "el-upload" ? (openBlock(), createBlock(_component_el_form_item, {
                                  key: 5,
                                  label: item.label,
                                  prop: key,
                                  rules: item.rules
                                }, {
                                  default: withCtx(() => [
                                    createVNode(_component_el_upload, mergeProps({ action: "" }, formComponentProps(item.formProps)), {
                                      default: withCtx(() => [
                                        item.formProps.listType !== "picture-card" ? (openBlock(), createBlock(_component_el_button, {
                                          key: 0,
                                          type: "primary",
                                          disabled: componentState(item, "disabled")
                                        }, {
                                          default: withCtx(() => [
                                            createTextVNode(toDisplayString(item.formProps.title), 1)
                                          ]),
                                          _: 2
                                        }, 1032, ["disabled"])) : (openBlock(), createBlock(_component_el_icon, { key: 1 }, {
                                          default: withCtx(() => [
                                            createVNode(_component_plus)
                                          ]),
                                          _: 1
                                        }))
                                      ]),
                                      _: 2
                                    }, 1040)
                                  ]),
                                  _: 2
                                }, 1032, ["label", "prop", "rules"])) : createCommentVNode("", true)
                              ], 64);
                            }), 128)),
                            renderSlot(_ctx.$slots, "edit-form-bottom-item", {
                              editModel: editModel.value,
                              handleSubmit,
                              CrudState
                            }, void 0, true)
                          ]),
                          _: 3
                        }, 8, ["model", "label-width"])
                      ]),
                      _: 3
                    })
                  ]),
                  _: 3
                })
              ]),
              _: 2
            }, [
              unref(DialogVisibleFooterButton) ? {
                name: "footer",
                fn: withCtx(() => [
                  createVNode(_component_el_button, {
                    onClick: _cache[3] || (_cache[3] = ($event) => DialogVisible.value = false)
                  }, {
                    default: withCtx(() => [
                      _hoisted_4
                    ]),
                    _: 1
                  }),
                  createVNode(_component_el_button, {
                    type: "primary",
                    loading: submitLoading.value,
                    onClick: _cache[4] || (_cache[4] = ($event) => handleSubmit(FormRef.value))
                  }, {
                    default: withCtx(() => [
                      _hoisted_5
                    ]),
                    _: 1
                  }, 8, ["loading"])
                ])
              } : void 0
            ]), 1032, ["modelValue", "title"])
          ]),
          _: 3
        })
      ], 4);
    };
  }
});
const index_vue_vue_type_style_index_0_scoped_d3110cef_lang = "";
const _export_sfc = (sfc, props) => {
  const target = sfc.__vccOpts || sfc;
  for (const [key, val] of props) {
    target[key] = val;
  }
  return target;
};
const CrudEl = /* @__PURE__ */ _export_sfc(_sfc_main, [["__scopeId", "data-v-d3110cef"]]);
const permission = {
  mounted(el, binding, vnode) {
    const permission2 = binding.value.permission;
    const access = binding.value.access;
    let Boole = false;
    for (let i = 0; i < access.length; i++) {
      if (permission2.includes(access[i])) {
        Boole = true;
        break;
      } else
        Boole = false;
    }
    if (!Boole) {
      el.parentNode && el.parentNode.removeChild(el);
    }
  }
};
CrudEl.install = (app) => {
  app.component("CrudEl", CrudEl);
  app.directive("permission", permission);
};
const createCrudEl = (app, options) => {
  if (options) {
    if (!options.CrudRequest)
      console.error("\u8BF7\u914D\u7F6E\u5168\u5C40\u8BF7\u6C42\u7684\u4E3B\u65B9\u6CD5\uFF1ACrudRequest");
    InitSystem(options);
    app.use(CrudEl);
  } else {
    console.error("\u8BF7\u521D\u59CB\u5316CrudEl\u914D\u7F6E\u9879");
  }
};
export {
  DataMerger,
  DeepClone,
  InitSystem,
  createCrudEl,
  hooksName,
  isObjEqual,
  useHooks
};
